# Step 1: Bring Software Assets Information to SAP LeanIX
### On this page
  * [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-import-software-assets#servicenow-integration)
  * [Integration with Configuration Management Databases (CMDB)](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-import-software-assets#integration-with-configuration-management-databases-\(cmdb\))
  * [Next Step](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-import-software-assets#next-step)


Learn efficient methods for gathering software asset information to build your inventory for effective obsolescence risk management.
To start your first technology risk assessment, build a comprehensive inventory of your software assets, which includes building an IT component repository. SAP LeanIX provides various methods for bringing needed information to the workspace, including manual entry, excel imports, surveys, to-dos, and integration with ServiceNow and other CMDBs.
